@@ -20,9 +20,9 @@
 """Uses speech prompts and a command line interface to set Orca
 user preferences."""
 
-__id__        = "$Id: orca_console_prefs.py 4563 2009-02-16 21:50:08Z wwalker $"
-__version__   = "$Revision: 4563 $"
-__date__      = "$Date: 2009-02-16 16:50:08 -0500 (Mon, 16 Feb 2009) $"
+__id__        = "$Id$"
+__version__   = "$Revision$"
+__date__      = "$Date$"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -33,7 +33,6 @@ import settings
 import speech
 import speechserver
 import orca_prefs
-import platform
 import time
 
 desktopRunning = False
@@ -172,7 +171,12 @@ def setupSpeech(prefsDict):
 
         # Translators: this is prompting for a numerical choice.
         #
-        choice = int(sayAndPrint(_("Enter choice: "), False, True))
+        while True:
+            try:
+                choice = int(sayAndPrint(_("Enter choice: "), False, True))
+                break
+            except:
+                pass
         if (choice <= 0) or (choice >= i):
             # Translators: this means speech synthesis will not be used.
             #
@@ -204,7 +208,12 @@ def setupSpeech(prefsDict):
 
         # Translators: this is prompting for a numerical choice.
         #
-        choice = int(sayAndPrint(_("Enter choice: "), False, True))
+        while True:
+            try:
+                choice = int(sayAndPrint(_("Enter choice: "), False, True))
+                break
+            except:
+                pass
         if (choice <= 0) or (choice >= i):
             # Translators: this means speech synthesis will not be used.
             #
@@ -251,10 +260,15 @@ def setupSpeech(prefsDict):
 
         # Translators: this is prompting for a numerical choice.
         #
-        choice = int(sayAndPrint(_("Enter choice: "),
-                                 False,               # stop
-                                 True,                # getInput
-                                 speechServerChoice)) # speech server
+        while True:
+            try:
+                choice = int(sayAndPrint(_("Enter choice: "),
+                                         False,               # stop
+                                         True,                # getInput
+                                         speechServerChoice)) # speech server
+                break
+            except:
+                pass
         if (choice <= 0) or (choice >= i):
             # Translators: this means speech synthesis will not be used.
             #
@@ -397,13 +411,15 @@ def setupSpeech(prefsDict):
     sayAndPrint(_("2. Laptop"),
                 False, False, speechServerChoice, speechVoiceChoice)
 
-    try:
-        # Translators: this is prompting for a numerical choice.
-        #
-        choice = int(sayAndPrint(_("Enter choice: "),
-                     False, True, speechServerChoice, speechVoiceChoice))
-    except:
-        choice = -1
+    while True:
+        try:
+            # Translators: this is prompting for a numerical choice.
+            #
+            choice = int(sayAndPrint(_("Enter choice: "),
+                         False, True, speechServerChoice, speechVoiceChoice))
+            break
+        except:
+            pass
     if choice == 2:
         prefsDict["keyboardLayout"] = settings.GENERAL_KEYBOARD_LAYOUT_LAPTOP
         prefsDict["orcaModifierKeys"] = settings.LAPTOP_MODIFIER_KEYS
@@ -416,19 +432,13 @@ def setupSpeech(prefsDict):
     return True
 
 def logoutUser():
-    """Automatically log the user out of the GNOME desktop."""
+    """Log the user out of the desktop."""
 
-    import gnome
-    import gnome.ui
-
-    gnome.init(platform.package, platform.version)
-    client = gnome.ui.master_client()
-
-    client.request_save(gnome.ui.SAVE_GLOBAL,  # Save style
-                        True,                  # Shutdown
-                        gnome.ui.INTERACT_ANY, # Allow user interaction
-                        False,                 # Fast
-                        True)                  # All apps save state
+    import dbus
+    bus = dbus.SessionBus()
+    sessionManager = bus.get_object('org.gnome.SessionManager',
+                                    '/org/gnome/SessionManager')
+    sessionManager.Logout(dbus.types.UInt32(1))
 
 def showPreferencesUI(commandLineSettings):
     """Uses the console to query the user for Orca preferences."""
