@@ -1090,7 +1090,11 @@ setScriptMapping(re.compile('[Ff]irefox'), "Mozilla")
 # version of Thunderbird, which chooses to now call itself by a different
 # name.
 #
-setScriptMapping(re.compile(_('Shredder')), "Thunderbird")
+#setScriptMapping(re.compile(_('Shredder')), "Thunderbird")
+#
+# Don't localize this. It seems to be messing us up. See bug 584103.
+#
+setScriptMapping(re.compile('Shredder'), "Thunderbird")
 
 # Translators: see the regular expression note above.  This is for
 # the Thunderbird e-mail application.
@@ -1111,6 +1115,7 @@ setScriptMapping(re.compile(_('vte')), "gnome-terminal")
 # supporting gaim, which has recently be renamed to pidgin.
 #
 setScriptMapping(re.compile(_('gaim')), "pidgin")
+setScriptMapping(re.compile('Pidgin'), "pidgin")
 
 # Translators: see the regular expression note above.  This is for
 # supporting yelp, which sometimes identifies itself as gnome-help.
@@ -1122,6 +1127,11 @@ setScriptMapping(re.compile(_('gaim')), "pidgin")
 #setScriptMapping(re.compile(_('gnome-help')), "yelp")
 setScriptMapping(re.compile('gnome-help'), "yelp")
 
+# Strip off the extra 'py' that the Device Driver Utility includes
+# as part of its accessible name.
+#
+setScriptMapping(re.compile('ddu.py'), "ddu")
+
 # Show deprecated messeges in debug output.
 # Set this to True to help find potential pyatspi porting problems
 #
