@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2005-2007 Sun Microsystems Inc.
+# Copyright 2005-2008 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -14,8 +14,8 @@
 #
 # You should have received a copy of the GNU Library General Public
 # License along with this library; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
+# Boston MA  02110-1301 USA.
 
 """Provides an abtract class for working with speech servers.
 
@@ -24,16 +24,18 @@ machine to speak.  Each speech server provides a set of known
 voices (identified by name) which can be combined with various
 attributes to create aural style sheets."""
 
-__id__        = "$Id: speechserver.py 3307 2007-11-30 18:41:19Z richb $"
-__version__   = "$Revision: 3307 $"
-__date__      = "$Date: 2007-11-30 13:41:19 -0500 (Fri, 30 Nov 2007) $"
-__copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
+__id__        = "$Id$"
+__version__   = "$Revision$"
+__date__      = "$Date$"
+__copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import logging
 import keynames
 import settings
 import orca
+import orca_state
+
 log = logging.getLogger("speech")
 
 import debug
@@ -200,6 +202,9 @@ class SpeechServer(object):
         # this key event.
         #
         event_string = keynames.getKeyName(event_string)
+        if orca_state.activeScript and orca_state.usePronunciationDictionary:
+            event_string = \
+                orca_state.activeScript.adjustForPronunciation(event_string)
 
         if eventType == orca.KeyEventType.LOCKING_LOCKED:
             # Translators: this represents the state of a locking modifier
